require "scripts/levelselect.lua"
require "scripts/loadlevel.lua"
require "scripts/gameplay.lua"
require "scripts/titlescreen.lua"
require "scripts/backgrounds/bg1.lua"
require "scripts/options.lua"

function love.load()
	--load resources
	image_spikeball=love.graphics.newImage("images/spikeball.png")	
	image_wall=love.graphics.newImage("images/wall.png")
	image_spring=love.graphics.newImage("images/spring.png")
	image_particle=love.graphics.newImage("images/particle.png")
	image_ball=love.graphics.newImage("images/ball.png")
	image_goal=love.graphics.newImage("images/goal.png")
	image_shrapnel=love.graphics.newImage("images/shrapnel.png")
	image_title=love.graphics.newImage("images/title.png")
	
	font_verasans20=love.graphics.newFont(20)
	font_verasans15=love.graphics.newFont(15)
	font_verasans30=love.graphics.newFont(30)
	
	--filesystem stuff
	love.filesystem.setIdentity("tesselode_tilt")
	love.filesystem.mkdir("custom")
	
	--start on title screen
	screen="titlescreen"
	titlescreen_load()
	levelselect_load()
	options_load()
	
	--options
	tilt_config_load()

	bg1_load() --start first background
end

function love.update()
	bg1_update() --update background
	
	if screen=="titlescreen" or screen=="levelselect" or screen=="options" then
		titlescreen_update()
		levelselect_update()
		options_update()
	end

	if screen=="gameplay" then
		gameplay_update()
	end
end

function love.keypressed(key)
	if key=="escape" then --escape key
		if screen=="gameplay" then --gameplay screen
			if overlay_mode=="off" then --pause menu
				if gameplay_paused==0 then gameplay_paused=1 else gameplay_paused=0 end
			else --overlay
				screen="levelselect"
			end
		elseif screen=="levelselect" then --level select screen
			screen="titlescreen"
		end
	end
end

function love.mousepressed(x,y,button) --button clicking
	if button=="l" then --left mouse button
		if screen=="titlescreen" then --title screen
			if titlescreen_selected==1 then
				levelselect_load()
				screen="levelselect"
			elseif titlescreen_selected==2 then
				screen="options"
			elseif titlescreen_selected==3 then
				love.event.push("q")
			end
		elseif screen=="levelselect" and numlevels>0 and selectedfile>0 then --level select stuff
			loadlevel("custom/"..levelpath[selectedfile])
			createlevel()
			gameplay_load()
			screen="gameplay"
			overlay_load()
			animation_load()
			pausemenu_load()
		elseif screen=="options" then --options screen
			if options_selected==1 then controlstyle=1
			elseif options_selected==2 then controlstyle=2
			elseif options_selected==3 then
				screen="titlescreen"
				tilt_config_write()
			end
		elseif screen=="gameplay" then --gameplay stuff
			if overlay_mode=="start" or overlay_mode=="retry" then
				overlay_mode="off"
				ball=love.physics.newBody(world,ball_spawn.x,ball_spawn.y,10,1) --create ball at spawn point
				ball_shape=love.physics.newCircleShape(ball,0,0,16)
				ball_shape:setData("ball")
				ball_shape:setCategory(2)
				ball:setBullet(true)
				particle_ball:stop()
			elseif gameplay_paused==1 then --pause menu
				if pausemenu_selected==1 then
					gameplay_paused=0
				elseif pausemenu_selected==2 then
					createlevel()
					gameplay_load()
					ball=love.physics.newBody(world,ball_spawn.x,ball_spawn.y,10,1) --reset ball
					ball_shape=love.physics.newCircleShape(ball,0,0,16)
					ball_shape:setData("ball")
					ball_shape:setCategory(2)
					ball:setBullet(true)
					particle_ball:stop()
					gameplay_paused=0 --unpause
				elseif pausemenu_selected==3 then
					screen="levelselect"
				end
			end
		end
	end
end

function love.draw()
	bg1_draw() --draw background
	
	if screen=="gameplay" then
		gameplay_draw()
	end
	
	if screen=="titlescreen" or screen=="levelselect" or screen=="options" then
		titlescreen_draw()
		levelselect_draw()
		options_draw()
	end
end
