require "scripts/gameplay/animations.lua"
require "scripts/gameplay/pausemenu.lua"
require "scripts/gameplay/overlay.lua"

function gameplay_load()
	mousex=love.mouse.getX() --variables for tracking mouse movement
	mousey=love.mouse.getY()
	mousex_previous=love.mouse.getX()
	mousey_previous=love.mouse.getY()
	
	world:setAllowSleep(false) --keeps platforms from freezing up
	world:setCallbacks(collision_new,collision_persist,collision_end,collision_result)
end

function gameplay_update()
	animation_update()
	pausemenu_update()
	overlay_update()
	
	--track mouse movement
	mousex_previous=mousex
	mousey_previous=mousey
	mousex=love.mouse.getX() 
	mousey=love.mouse.getY()
	
	--snap mouse to center if control style 2 is being used
	if controlstyle==2 and overlay_mode=="off" and gameplay_paused==0 then
		love.mouse.setPosition(400,300)
		love.mouse.setVisible(false)
	else
		love.mouse.setVisible(true)
	end
	
	local a
	for a=1,objectnum-1 do
		if object[a].kind=="platform" then
			if platform_active[a]==1 and (love.mouse.isDown("l") or controlstyle==2) and overlay_mode=="off" then --rotate platforms
				if controlstyle==2 then
					platform[a]:setAngularVelocity(math.rad(((love.mouse.getX()-400)+(love.mouse.getY()-300)/3)/love.timer.getDelta()))
				else
					platform[a]:setAngularVelocity(math.rad(((mousex-mousex_previous)+(mousey-mousey_previous))/3)/love.timer.getDelta())
				end
			else
				platform[a]:setAngularVelocity(0)
			end
			
			--limit platform rotation speed
			local rotspeedlimit=platform_size[a]/300
			if rotspeedlimit<1 then rotspeedlimit=1 end
			
			if platform[a]:getAngularVelocity()>math.rad(300/rotspeedlimit) then platform[a]:setAngularVelocity(math.rad(300/rotspeedlimit)) end
			if platform[a]:getAngularVelocity()<math.rad(-300/rotspeedlimit) then platform[a]:setAngularVelocity(math.rad(-300/rotspeedlimit)) end

			platform[a]:setX(object[a].x) --keep ball from pushing platforms
			platform[a]:setY(object[a].y)
		end	
	end
	
	if overlay_mode=="off" then --limit ball speed
		local x,y=ball:getLinearVelocity()
		if x>400 then ball:setLinearVelocity(400,y) end
		if x<-400 then ball:setLinearVelocity(-400,y) end
		if y>400 then ball:setLinearVelocity(x,400) end
		if y<-400 then ball:setLinearVelocity(x,-400) end
	end
	
	--check if ball goes off screen
	if overlay_mode=="off" then
		if ball:isFrozen() or ball:getX()<-16 or ball:getY()>love.graphics.getWidth()+16 then
			createlevel()
			gameplay_load()
			overlay_mode="retry"
		end
	end
	
	for a=1,objectnum-1 do --cause ball to be pushed by air jets
		if object[a].kind=="jet" and ball then
			if jet_direction[a]=="right" then
				if ball:getX()>object[a].x and ball:getY()>object[a].y-20 and ball:getY()<object[a].y+20 then
					ball:applyForce(500-(ball:getX()-object[a].x),0)
				end
				
			elseif jet_direction[a]=="left" then
				if ball:getX()<object[a].x and ball:getY()>object[a].y-20 and ball:getY()<object[a].y+20 then
					ball:applyForce(-500-(ball:getX()-object[a].x),0)
				end
				
			elseif jet_direction[a]=="up" then
				if ball:getY()<object[a].y and ball:getX()>object[a].x-20 and ball:getX()<object[a].x+20 then
					ball:applyForce(0,-500-(ball:getY()-object[a].y))
				end
			
			elseif jet_direction[a]=="down" then
				if ball:getY()>object[a].y and ball:getX()>object[a].x-20 and ball:getX()<object[a].x+20 then
					ball:applyForce(0,500-(ball:getY()-object[a].y))
				end
			end
		end
	end
	
	if gameplay_paused==0 then
		world:update(love.timer.getDelta())
	end
end

function collision_new(first,second,contact)
	if first=="goal" and second=="ball" then --check if ball meets goal
		overlay_mode="clear" --show level clear mesesage
		ball_remnant={x=ball:getX(),y=ball:getY(),alpha=1,size=1} --set parameters for level clear animation
		
		particle_clear=love.graphics.newParticleSystem(image_particle,50) --create level clear particle system
		particle_clear:setColor(255,255,255,255,255,255,255,0)
		particle_clear:setLifetime(1)
		particle_clear:setEmissionRate(20)
		particle_clear:setParticleLife(2)
		particle_clear:setSpeed(100,110)
		particle_clear:setSpread(math.rad(360))
		particle_clear:setPosition(ball:getX(),ball:getY())
		
		ball:setX(-5000) --keep ball from triggering collision multiple times - would use ball:destroy but that causes some pretty horrible errors
		ball:setY(-5000)
	end
	
	if first=="ball" and second=="spike" then --check if ball hits spikes
		createlevel() --reset level
		gameplay_load()
		overlay_mode="retry" --show retry message
		
		ball_remnant={x=ball:getX(),y=ball:getY(),alpha=1,size=1} --set parameters for death animation (same as level clear)
		
		particle_death=love.graphics.newParticleSystem(image_particle,50) --create death particle system
		particle_death:setColor(255,0,0,255,255,0,0,0)
		particle_death:setLifetime(1)
		particle_death:setEmissionRate(20)
		particle_death:setParticleLife(2)
		particle_death:setSpeed(100,110)
		particle_death:setSpread(math.rad(360))
		particle_death:setPosition(ball:getX(),ball:getY())
		
		ball:setX(-50) --see above
		ball:setY(-50)
	end
	
	if first=="spike" and second=="ball" then --in case the collision stuff gets reversed
		createlevel()
		gameplay_load()
		overlay_mode="retry"
		
		ball_remnant={x=ball:getX(),y=ball:getY(),alpha=1,size=1}
		
		particle_death=love.graphics.newParticleSystem(image_particle,50)
		particle_death:setColor(255,0,0,255,255,0,0,0)
		particle_death:setLifetime(1)
		particle_death:setEmissionRate(20)
		particle_death:setParticleLife(2)
		particle_death:setSpeed(100,110)
		particle_death:setSpread(math.rad(360))
		particle_death:setPosition(ball:getX(),ball:getY())
		
		ball:setX(-50) --see above
		ball:setY(-50)
	end
	
	local a --bounce ball off springs
	for a=1,objectnum-1 do
		if object[a].kind=="spring" then
			if first=="spring"..tostring(a) and second=="ball" then
				ball:applyImpulse(0,-150)
				spring_color[a]=128
			end
		end
	end
	
	local b --activate platforms when ball touches them
	for a=1,objectnum-1 do
		if first=="platform"..tostring(a) and second=="ball" then
			for b=1,objectnum-1 do
				platform_active[b]=0
			end
			platform_active[a]=1
		end
	end
end

function gameplay_draw()
	--draw physics stuff - arranged in drawing order!
	local a, b
	for a=1,objectnum-1 do
		if object[a].kind=="platform" then --draw platform shapes
			if platform_active[a]==1 then
				love.graphics.setColor(255,0,0,255)
			else
				love.graphics.setColor(255,255,255,255)
			end
			
			for b=1,shape_amount[a] do
				love.graphics.polygon("fill",platform_shape[a][b]:getPoints())
			end
		end
	end
	
	for a=1,objectnum-1 do --draw other stuff
		if object[a].kind=="ball" and overlay_mode=="off" then --draw ball
			love.graphics.setColor(255,255,255,255)
			love.graphics.draw(image_ball,ball:getX(),ball:getY(),ball:getAngle(),1,1,16,16)
		end
		
		if object[a].kind=="goal" then --draw goal
			love.graphics.setColor(0,255,0,150)
			love.graphics.draw(image_goal,goal:getX(),goal:getY(),math.rad(goal_angle_1),1,1,16,16)
			love.graphics.draw(image_goal,goal:getX(),goal:getY(),math.rad(goal_angle_2),1,1,16,16)
			love.graphics.draw(image_goal,goal:getX(),goal:getY(),math.rad(goal_angle_3),1,1,16,16)
		end
		
		if object[a].kind=="wall" then --draw wall
			love.graphics.setColor(255,255,255,255)
			love.graphics.draw(image_wall,wall[a]:getX(),wall[a]:getY(),0,1,1,16,16)
		end
		
		if object[a].kind=="spike" then --draw spikeballs
			love.graphics.setColor(255,255,255,255)
			love.graphics.draw(image_spikeball,spike[a]:getX(),spike[a]:getY(),0,1,1,15,15)
		end

		if object[a].kind=="spring" then --draw springs
			love.graphics.setColor(spring_color[a],spring_color[a],255,255)
			love.graphics.draw(image_spring,spring[a]:getX(),spring[a]:getY(),0,1,1,15,15)
		end
	end
	
	animation_draw()
	pausemenu_draw()
	overlay_draw()
end
