function loadlevel(filename) --loads variables used for creating levels
	local file=love.filesystem.newFile(filename)
	file:open("r")

	--some random variables
	objectnum=1
	shapenum={}
	object={}
	shape={}
	shape_amount={}
	jet_direction={}
	platform_size={} --used to adjust rotation speeds of platforms
	
	for line in file:lines() do --load data for objects
		local currentline=line
		object[objectnum]={x=0,y=0,kind=""}
		
		object[objectnum].x=tonumber(string.sub(currentline,1,string.find(currentline,",")-1)) --get coordinates of object
		currentline=string.sub(currentline,string.find(currentline,",")+1)
		object[objectnum].y=tonumber(string.sub(currentline,1,string.find(currentline,",")-1))
		currentline=string.sub(currentline,string.find(currentline,",")+1)
		
		if string.find(currentline,",") then --check if line ends with object type
			object[objectnum].kind=string.sub(currentline,1,string.find(currentline,",")-1)
		else
			object[objectnum].kind=currentline
		end
		
		if object[objectnum].kind=="platform" then --load shape data if object is platform
			shape[objectnum]={}
			platform_size[objectnum]=0
			shapenum=1
			while string.find(currentline,",") do
				shape[objectnum][shapenum]={x=0,y=0,width=0,height=0}
				
				currentline=string.sub(currentline,string.find(currentline,",")+1)
				shape[objectnum][shapenum].x=tonumber(string.sub(currentline,1,string.find(currentline,",")-1))
				currentline=string.sub(currentline,string.find(currentline,",")+1)
				shape[objectnum][shapenum].y=tonumber(string.sub(currentline,1,string.find(currentline,",")-1))
				currentline=string.sub(currentline,string.find(currentline,",")+1)
				shape[objectnum][shapenum].width=tonumber(string.sub(currentline,1,string.find(currentline,",")-1))
				currentline=string.sub(currentline,string.find(currentline,",")+1)
				
				if shape[objectnum][shapenum].width>platform_size[objectnum] then platform_size[objectnum]=shape[objectnum][shapenum].width end --calculate platform size
				
				if string.find(currentline,",") then	
					shape[objectnum][shapenum].height=tonumber(string.sub(currentline,1,string.find(currentline,",")-1))
				else
					shape[objectnum][shapenum].height=tonumber(currentline)
				end
				
				if shape[objectnum][shapenum].height>platform_size[objectnum] then platform_size[objectnum]=shape[objectnum][shapenum].height end --calculate platform size
				
				shapenum=shapenum+1
			end
			shape_amount[objectnum]=shapenum-1
		end
		
		if object[objectnum].kind=="jet" then --get direction of jet
			currentline=string.sub(currentline,string.find(currentline,",")+1)
			jet_direction[objectnum]=currentline
		end
		
		objectnum=objectnum+1
	end
	file:close()
end

function createlevel() --create physics stuff from loaded level data
	--more random variables
	anchor={} --static bodies
	platform={} --dynamic bodies
	platform_active={} --for allowing one platform to be controlled at a time
	platform_shape={} --obvious
	joint={} --revolute joints connecting anchors and platforms
	wall={} --uninteractive walls
	wall_shape={} --what else?
	spike={} --balls + spikes =/= a good thing :P
	spike_shape={} --I'm going to stop now
	spring={}
	spring_shape={}
	spring_color={} --for animation purposes
	particle_jet={} --particle systems for air jets

	world=love.physics.newWorld(love.graphics.getWidth(),love.graphics.getHeight()) --create world
	world:setGravity(0,500)

	local a, b
	for a=1,objectnum-1 do
		if object[a].kind=="ball" then --ball spawn point + particle system
			ball_spawn={x=object[a].x,y=object[a].y}
			particle_ball=love.graphics.newParticleSystem(image_particle,20)
			particle_ball:setColor(150,150,255,255,150,150,255,0)
			particle_ball:setEmissionRate(4)
			particle_ball:setSpeed(30,40)
			particle_ball:setSpread(math.rad(360))
			particle_ball:setParticleLife(3)
		end
		
		if object[a].kind=="goal" then --create goal
			goal=love.physics.newBody(world,object[a].x,object[a].y)
			goal_shape=love.physics.newRectangleShape(goal,0,0,32,32)
			goal_shape:setData("goal")
			
			--create goal particle system
			if particle_goal==nil then --don't create particle system if it already exists - keeps animation from restarting on ball death
				particle_goal=love.graphics.newParticleSystem(image_particle,20)
				particle_goal:setColor(0,255,0,255,0,255,0,0)
				particle_goal:setEmissionRate(3)
				particle_goal:setTangentialAcceleration(10,20)
				particle_goal:setSpeed(10,20)
				particle_goal:setSpread(math.rad(360))
				particle_goal:setParticleLife(5)
			end
		end
		
		if object[a].kind=="wall" then --create wall
			wall[a]=love.physics.newBody(world,object[a].x,object[a].y)
			wall_shape[a]=love.physics.newRectangleShape(wall[a],0,0,30,30)
		end
		
		if object[a].kind=="spike" then --create spikeball
			spike[a]=love.physics.newBody(world,object[a].x,object[a].y)
			spike_shape[a]=love.physics.newCircleShape(spike[a],0,0,15)
			spike_shape[a]:setData("spike")
		end

		if object[a].kind=="spring" then --create spring
			spring[a]=love.physics.newBody(world,object[a].x,object[a].y)
			spring_shape[a]=love.physics.newRectangleShape(spring[a],0,0,30,30)
			spring_shape[a]:setData("spring"..tostring(a))
			spring_shape[a]:setFriction(0)
			spring_color[a]=255
		end
		
		if object[a].kind=="jet" then --create particle systems for jets
			particle_jet[a]=love.graphics.newParticleSystem(image_particle,100)
			
			if jet_direction[a]=="left" then particle_jet[a]:setDirection(math.rad(180))
			elseif jet_direction[a]=="right" then particle_jet[a]:setDirection(math.rad(0))
			elseif jet_direction[a]=="up" then particle_jet[a]:setDirection(math.rad(270))
			elseif jet_direction[a]=="down" then particle_jet[a]:setDirection(math.rad(90)) end
			
			particle_jet[a]:setColor(230,230,255,255,230,230,255,0)
			particle_jet[a]:setEmissionRate(10)
			particle_jet[a]:setParticleLife(3,5)
			particle_jet[a]:setSpeed(150,200)
			particle_jet[a]:setSpread(math.rad(30))
			particle_jet[a]:setTangentialAcceleration(-10,10)
		end
		
		if object[a].kind=="platform" then --create plaforms
			anchor[a]=love.physics.newBody(world,object[a].x,object[a].y)
			
			platform_active[a]=0
			platform_shape[a]={}
			platform[a]=love.physics.newBody(world,object[a].x,object[a].y,1,0)
			for b=1,shape_amount[a] do --attach shapes to platforms
				platform_shape[a][b]=love.physics.newRectangleShape(platform[a],shape[a][b].x,shape[a][b].y,shape[a][b].width,shape[a][b].height)
				platform_shape[a][b]:setData("platform"..tostring(a))
				platform_shape[a][b]:setMask(1)
				platform_shape[a][b]:setFriction(0.05)
				platform_shape[a][b]:setRestitution(0)
			end
			platform[a]:setBullet(true)
			
			joint[a]=love.physics.newRevoluteJoint(anchor[a],platform[a],object[a].x,object[a].y)
		end
	end
end
